@@ -21,11 +21,11 @@ import (
 	"k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	k8sjson "k8s.io/apimachinery/pkg/runtime/serializer/json"
 	"k8s.io/apimachinery/pkg/util/diff"
 	"k8s.io/apimachinery/pkg/util/wait"
-	watch "k8s.io/apimachinery/pkg/watch"
 	"k8s.io/apiserver/pkg/storage/names"
 	k8sscheme "k8s.io/client-go/kubernetes/scheme"
 
@@ -311,11 +311,13 @@ func registryPodHealthy(address string) bool {
 }
 
 func catalogSourceRegistryPodSynced(catalog *v1alpha1.CatalogSource) bool {
-	if !catalog.Status.LastSync.IsZero() && catalog.Status.RegistryServiceStatus != nil {
-		fmt.Printf("catalog %s pod with address %s\n", catalog.GetName(), catalog.Status.RegistryServiceStatus.Address())
-		return registryPodHealthy(catalog.Status.RegistryServiceStatus.Address())
+	registry := catalog.Status.RegistryServiceStatus
+	connState := catalog.Status.GRPCConnectionState
+	if registry != nil && connState != nil && !connState.LastConnectTime.IsZero() {
+		fmt.Printf("catalog %s pod with address %s\n", catalog.GetName(), registry.Address())
+		return registryPodHealthy(registry.Address())
 	}
-	fmt.Println("waiting for catalog pod to be available")
+	fmt.Printf("waiting for catalog pod %v to be available (for sync)\n", catalog.GetName())
 	return false
 }
 
@@ -531,28 +533,24 @@ func serializeObject(obj interface{}) string {
 	return string(bytes)
 }
 
-type conditionChecker interface {
-	conditionMet(t *testing.T, event watch.Event) (met bool)
+func createCR(c operatorclient.ClientInterface, item *unstructured.Unstructured, apiGroup, version, namespace, resourceKind, resourceName string) (cleanupFunc, error) {
+	err := c.CreateCustomResource(item)
+	if err != nil {
+		return nil, err
+	}
+	return buildCRCleanupFunc(c, apiGroup, version, namespace, resourceKind, resourceName), nil
 }
 
-type conditionMetFunc func(t *testing.T, event watch.Event) (met bool)
-
-func (c conditionMetFunc) conditionMet(t *testing.T, event watch.Event) bool {
-	return c(t, event)
-}
-
-func awaitCondition(ctx context.Context, t *testing.T, w watch.Interface, checker conditionChecker) {
-	met := false
-	for !met {
-		select {
-		case <-ctx.Done():
-			require.NoError(t, ctx.Err())
-			return
-		case event, ok := <-w.ResultChan():
-			if !ok {
-				return
-			}
-			met = checker.conditionMet(t, event)
+func buildCRCleanupFunc(c operatorclient.ClientInterface, apiGroup, version, namespace, resourceKind, resourceName string) cleanupFunc {
+	return func() {
+		err := c.DeleteCustomResource(apiGroup, version, namespace, resourceKind, resourceName)
+		if err != nil {
+			fmt.Println(err)
 		}
+
+		waitForDelete(func() error {
+			_, err := c.GetCustomResource(apiGroup, version, namespace, resourceKind, resourceName)
+			return err
+		})
 	}
 }
