@@ -5,6 +5,7 @@ package tools
 import (
 	_ "github.com/golang/mock/mockgen"
 	_ "github.com/maxbrunsfeld/counterfeiter/v6"
+	_ "github.com/mikefarah/yq/v2"
 	_ "k8s.io/code-generator/cmd/client-gen"
 	_ "k8s.io/code-generator/cmd/conversion-gen/"
 	_ "k8s.io/code-generator/cmd/deepcopy-gen"
@@ -13,6 +14,8 @@ import (
 	_ "k8s.io/code-generator/cmd/import-boss"
 	_ "k8s.io/code-generator/cmd/informer-gen"
 	_ "k8s.io/code-generator/cmd/lister-gen"
+	_ "k8s.io/code-generator/cmd/openapi-gen"
 	_ "k8s.io/code-generator/cmd/set-gen"
 	_ "k8s.io/kube-openapi/cmd/openapi-gen"
+	_ "sigs.k8s.io/controller-tools/cmd/controller-gen"
 )
